package de.intevation.gnv.action;

import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import de.intevation.gnv.action.sessionmodel.SessionModel;
import de.intevation.gnv.action.sessionmodel.SessionModelFactory;
import de.intevation.gnv.artifactdatabase.client.ArtifactDatabaseClient;
import de.intevation.gnv.artifactdatabase.client.ArtifactDatabaseClientFactory;
import de.intevation.gnv.artifactdatabase.objects.ArtifactStatisticsSet;

/**
 * This controller is used to display to statistic of the current
 * parameterization.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ShowStatisticAction extends DescribeUIAction {

    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger logger = Logger.getLogger(ShowStatisticAction.class);


    /**
     * Constructor
     */
    public ShowStatisticAction() {
        super();
    }


    @Override
    public ActionForward execute(
        ActionMapping       mapping,
        ActionForm          form,
        HttpServletRequest  request,
        HttpServletResponse response
    ) throws Exception
    {
        if (isSessionExhausted(request)) {
            return sessionExhaustedForward(mapping, form, request, response);
        }

        logger.info("show statistic");
        SessionModel sm = SessionModelFactory.getInstance().getSessionModel(
            request);

        ArtifactDatabaseClient adc = ArtifactDatabaseClientFactory.getInstance()
            .getArtifactDatabaseClient(getLocale(request));

        try{
            Collection<ArtifactStatisticsSet> statistics =
                adc.calculateStatistics(sm.getSelectedArtifactFactory(),
                sm.getCurrentArtifact());

            sm.setStatistics(statistics);

            request.setAttribute("statistic", true);
        }
        catch (Exception e) {
            logger.error(e, e);
        }

        return super.execute(mapping, form, request, response);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
